==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_soapcastle.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function GoSoapCastleEntrance()
    PRI()
    FAC("jack_normal")MS3("\n我们不会再变成鱼到海中了。")NOD()
    --PRI()FAO(3)TRA("CS_soapcastle_entrance","E0091",36,8,0,4)
end

function SwimSoapCastleEntrance()
    PRI()FAO(3)TRA("CS_soapcastle_entrance","E0091",38,17)
end

function GoSoapCastleJail()
    PRI()FAO(1)TRA("CS_soapcastle_jail","E0093",3,12)
end

function SwimSoapCastleJail()
    PRI()FAO(1)TRA("CS_soapcastle_jail","E0093",1,21)
end

function GoPuuRestaurant()
    PRI()FAO(1)TRA("CS_puu_restaurant","E0093",6,26,0,47)
end

function GoSoapCastleGolemHall()
    PRI()FAO(3)TRA("CS_soapcastle_golemhall","E0091",76,17,0,19)
end

function GoSoapCastleStoreRoom()
    PRI()FAO(1)TRA("CS_soapcastle_storeroom","E0093",7,16)
end

function GoSoapCastleWaterFall()
    if(FLJ("ExploreEscapeRoutes")) then
        PRI()FAO(3)TRA("CS_soapcastle_waterfall","E0091",75,17,0,4)
    else
        PRI()FAC("jack_normal")MS3("\n目前还不需要去那边。")NOD()
    end
end

function GoSoapCastlePuuRoom()
    if(FLJ("PuuRoomUnlock")) then
        PRI()FAO(3)TRA("CS_soapcastle_puuroom","E0091",34,13)
    elseif(FLJ("PlayedIronDyedAni")) then
        KEY()MS3("有怪物在里面，")NOD()
        CAT("\n现在进去会被发现的。")NOD()
    else
        KEY()
        MS3("\n里面似乎有什么动静...")NOD()CLO()
        PRI()FAO(3)
        HMC()
        POS(true)
        TRA("CS_soapcastle_puuroom","IronheadDyed",34,13)
    end
end

function GoSoapCastleTalaRoom()
    PRI()FAO(1)TRA("CS_soapcastle_talaroom","E0093",6,13)
end

function PlayedIronDyedAniEnd()
    PRI()
    POS(false)
    SMC()
    FLP("PlayedIronDyedAni")
    MNA()CMU("CS_Vivi")FAI(3)
end

--塔拉
function TalaCatchChako()
    KEY()
    FLS("PlayCastleAni")
    FLP("PlaceChakoToJail")
    HMC()
    SNP("CS_puu_animate",17,51,1,"mainLayer","Puu1")
    CMU("CS_Vivi")
    FAI(2)
    WAI(32)
    ANP("Puu1",0,0)
    WAI(32)
    FAC("puu_normal")MSG("\n塔拉这家伙怎么还不回来...")NOD()CLO()
    WAI(32)
    MS3("\n我来啦！！")NOD()CLO()
    SNP("CS_soapwalker_animate",9,41,1,"mainLayer","Tala1")
    ANP("Tala1","with_chako",0)
    ANP("Tala1",1060)
    WAI(128)
    ANP("Tala1","with_chako",1)
    WAI(64)
    FAC("puu_normal")MSG("哇！你哪抓到的？！")NOD()
    CAT("\n怎么还是只闪的。")NOD()CLR()
    FAC("soapwalker_normal")MSG("\n嘿嘿，不告诉你。")NOD()CLR()
    FAC("puu_normal")CAT("小气鬼...")NOD()CAT("算了，")NOD()
    CAT("\n不过这样我们就有4只了。")NOD()CLR()
    FAC("soapwalker_normal")CAT("但剩下的3只要怎么办？")NOD()
    CAT("\n就算拿去繁育的话不知道要多久。")NOD()CLR()
    CAT("你有把握能一直瞒大王")
    CAT("\n到你去黑市买一条新的龙鱼回来吗？")NOD()CLR()
    CAT("或者先把铁头刷成红色")
    CAT("\n和他看上去差不多的样子糊弄一下...")NOD()CLR()
    FAC("puu_normal")CAT("\n让我想想...")NOD()CLO()
    ANP("Puu1","normal",1)
    WAI(64)
    ANP("Puu1","normal",0)
    WAI(32)
    FAC("puu_normal")MSG("只能这么办了...")NOD()
    CAT("\n我去准备颜料，")NOD()
    CAT("\n你把它关进牢房里后，")NOD()
    CAT("\n就把铁头抓到我房间里来吧。")NOD()CLR()
    FAC("soapwalker_normal")CAT("\nOK————！")NOD()CLO()
    FAO(0)
    SMC("CS_mychar_jackfish_p1")
    SMC("CS_mychar_santafish_p2")
    SMC("CS_mychar_puppyfish_p3")
    TRA("CS_soapcastle_entrance","E0092",14,19)
end

function SoapKingGoResturant()
    KEY()
    SNP("CS_puu_animate",43,12,1,"mainLayer","Puu1")
    SNP("CS_soapking_animate",46,11,1,"mainLayer","Soapking1")
    FAC("puu_normal")MS3("\n大王您等一下！")NOD()CLO()
    FAI(2)
    WAI(32)
    ANP("Soapking1","normal",0)
    WAI(16)
    FAC()MS3("\n又怎么了？")NOD()CLR()
    FAC("puu_normal")CAT("\n里面其实还没打扫干净...")NOD()CLR()
    FAC()CAT("没关系的扑悠，")
    CAT("\n我不会在意的...")NOD()CLO()
    ANP("Soapking1","normal",1)
    WAI(16)
    ANP("Soapking1","walk",1)
    WAI(16)
    DNP("Soapking1")
    PMU(5)
    WAI(64)
    FAC("puu_normal")MS3("这下完蛋了，")NOD()
    ANP("Puu1","normal",0)
    CAT("\n我现在去塔拉房间")
    CAT("\n用传送器逃走还来得及嘛...")NOD()CLO()
    WAI(64)
    WAI(64)
    SNP("CS_soapking_animate",47,11,0,"mainLayer","Soapking1")
    WAI(16)
    ANP("Soapking1","walk",0)
    WAI(16)
    ANP("Soapking1","normal",0)
    WAI(16)
    ANP("Puu1","normal",1)
    WAI(32)
    RMU(5)
    MS3("话说你们最近没有照顾好库龙嘛？")NOD()
    CAT("\n它都瘦了一大圈，也很没精神，")NOD()
    CAT("\n我可不想看到它这个样子，")NOD()
    CAT("\n你们最好再加把劲把他照顾好。")NOD()CLR()
    CAT("\n我现在要去睡了...")NOD()CLR()
    FAC("puu_normal")MS3("\n好的大王。")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_puu_restaurant","IronheadDeadAni",8,26)
end

==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_soapcastle.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function GoSoapCastleEntrance()
    if(FLJ("HeroBack")) then
        PRI()FAO(3)TRA("CS_soapcastle_entrance","E0091",36,8,0,4)
    else
        PRI()
        FAC("jack_normal")MS3("\n我们不会再变成鱼到海中了。")NOD()
    end
end

function SwimSoapCastleEntrance()
    PRI()FAO(3)TRA("CS_soapcastle_entrance","E0091",38,17)
end

function GoSoapCastleJail()
    PRI()FAO(1)TRA("CS_soapcastle_jail","E0093",3,12)
end

function SwimSoapCastleJail()
    PRI()FAO(1)TRA("CS_soapcastle_jail","E0093",1,21)
end

function GoPuuRestaurant()
    PRI()FAO(1)TRA("CS_puu_restaurant","E0093",6,26,0,47)
end

function GoSoapCastleGolemHall()
    PRI()FAO(3)TRA("CS_soapcastle_golemhall","E0091",76,17,0,19)
end

function GoSoapCastleStoreRoom()
    PRI()FAO(1)TRA("CS_soapcastle_storeroom","E0093",7,16)
end

function GoSoapCastleWaterFall()
    if(FLJ("ExploreEscapeRoutes")) then
        PRI()FAO(3)TRA("CS_soapcastle_waterfall","E0091",75,17,0,4)
    else
        PRI()FAC("jack_normal")MS3("\n目前还不需要去那边。")NOD()
    end
end

function GoSoapCastlePuuRoom()
    if(FLJ("PuuRoomUnlock")) then
        PRI()FAO(3)TRA("CS_soapcastle_puuroom","E0091",34,13)
    elseif(FLJ("PlayedIronDyedAni")) then
        KEY()MS3("有怪物在里面，")NOD()
        CAT("\n现在进去会被发现的。")NOD()
    else
        KEY()
        MS3("\n里面似乎有什么动静...")NOD()CLO()
        PRI()FAO(3)
        HMC()
        POS(true)
        TRA("CS_soapcastle_puuroom","IronheadDyed",34,13)
    end
end

function GoSoapCastleTalaRoom()
    PRI()FAO(1)TRA("CS_soapcastle_talaroom","E0093",6,13)
end

function PlayedIronDyedAniEnd()
    PRI()
    POS(false)
    SMC()
    FLP("PlayedIronDyedAni")
    MNA()CMU("CS_Vivi")FAI(3)
end

--塔拉
function TalaCatchChako()
    KEY()
    FLS("PlayCastleAni")
    FLP("PlaceChakoToJail")
    HMC()
    SNP("CS_puu_animate",17,51,1,"mainLayer","Puu1")
    CMU("CS_Vivi")
    FAI(2)
    WAI(32)
    ANP("Puu1",0,0)
    WAI(32)
    FAC("puu_normal")MSG("\n塔拉这家伙怎么还不回来...")NOD()CLO()
    WAI(32)
    MS3("\n我来啦！！")NOD()CLO()
    SNP("CS_soapwalker_animate",9,41,1,"mainLayer","Tala1")
    ANP("Tala1","with_chako",0)
    ANP("Tala1",1060)
    WAI(128)
    ANP("Tala1","with_chako",1)
    WAI(64)
    FAC("puu_normal")MSG("哇！你哪抓到的？！")NOD()
    CAT("\n怎么还是只闪的。")NOD()CLR()
    FAC("soapwalker_normal")MSG("\n嘿嘿，不告诉你。")NOD()CLR()
    FAC("puu_normal")CAT("小气鬼...")NOD()CAT("算了，")NOD()
    CAT("\n不过这样我们就有4只了。")NOD()CLR()
    FAC("soapwalker_normal")CAT("但剩下的3只要怎么办？")NOD()
    CAT("\n就算拿去繁育的话不知道要多久。")NOD()CLR()
    CAT("你有把握能一直瞒大王")
    CAT("\n到你去黑市买一条新的龙鱼回来吗？")NOD()CLR()
    CAT("或者先把铁头刷成红色")
    CAT("\n和他看上去差不多的样子糊弄一下...")NOD()CLR()
    FAC("puu_normal")CAT("\n让我想想...")NOD()CLO()
    ANP("Puu1","normal",1)
    WAI(64)
    ANP("Puu1","normal",0)
    WAI(32)
    FAC("puu_normal")MSG("只能这么办了...")NOD()
    CAT("\n我去准备颜料，")NOD()
    CAT("\n你把它关进牢房里后，")NOD()
    CAT("\n就把铁头抓到我房间里来吧。")NOD()CLR()
    FAC("soapwalker_normal")CAT("\nOK————！")NOD()CLO()
    FAO(0)
    SMC("CS_mychar_jackfish_p1")
    SMC("CS_mychar_santafish_p2")
    SMC("CS_mychar_puppyfish_p3")
    TRA("CS_soapcastle_entrance","E0092",14,19)
end

function SoapKingGoResturant()
    KEY()
    SNP("CS_puu_animate",43,12,1,"mainLayer","Puu1")
    SNP("CS_soapking_animate",46,11,1,"mainLayer","Soapking1")
    FAC("puu_normal")MS3("\n大王您等一下！")NOD()CLO()
    FAI(2)
    WAI(32)
    ANP("Soapking1","normal",0)
    WAI(16)
    FAC()MS3("\n又怎么了？")NOD()CLR()
    FAC("puu_normal")CAT("\n里面其实还没打扫干净...")NOD()CLR()
    FAC()CAT("没关系的扑悠，")
    CAT("\n我不会在意的...")NOD()CLO()
    ANP("Soapking1","normal",1)
    WAI(16)
    ANP("Soapking1","walk",1)
    WAI(16)
    DNP("Soapking1")
    PMU(5)
    WAI(64)
    FAC("puu_normal")MS3("这下完蛋了，")NOD()
    ANP("Puu1","normal",0)
    CAT("\n我现在去塔拉房间")
    CAT("\n用传送器逃走还来得及嘛...")NOD()CLO()
    WAI(64)
    WAI(64)
    SNP("CS_soapking_animate",47,11,0,"mainLayer","Soapking1")
    WAI(16)
    ANP("Soapking1","walk",0)
    WAI(16)
    ANP("Soapking1","normal",0)
    WAI(16)
    ANP("Puu1","normal",1)
    WAI(32)
    RMU(5)
    MS3("话说你们最近没有照顾好库龙嘛？")NOD()
    CAT("\n它都瘦了一大圈，也很没精神，")NOD()
    CAT("\n我可不想看到它这个样子，")NOD()
    CAT("\n你们最好再加把劲把他照顾好。")NOD()CLR()
    CAT("\n我现在要去睡了...")NOD()CLR()
    FAC("puu_normal")MS3("\n好的大王。")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_puu_restaurant","IronheadDeadAni",8,26)
end
